#!/bin/sh

echo "\n-- dexA1_zgees.r:"
Rscript dexA1_zgees.r

echo "\n-- dexA1_zgeev.r:"
Rscript dexA1_zgeev.r

echo "\n-- dexA2_zgees.r:"
Rscript dexA2_dgees.r

echo "\n-- dexA2_dgeev.r:"
Rscript dexA2_dgeev.r

echo "\n-- dexA3_ztrsen.r:"
Rscript dexA3_ztrsen.r

echo "\n-- dexA4_dtrsen.r:"
Rscript dexA4_dtrsen.r

echo "\n-- dexAB1_zgges.r:"
Rscript dexAB1_zgges.r

echo "\n-- dexAB1_zggev.r:"
Rscript dexAB1_zggev.r

echo "\n-- dexAB2_dgges.r:"
Rscript dexAB2_dgges.r

echo "\n-- dexA2_dgeev.r:"
Rscript dexAB2_dggev.r

echo "\n-- dexAB3_ztgsen.r:"
Rscript dexAB3_ztgsen.r

echo "\n-- dexAB4_dtgsen.r:"
Rscript dexAB4_dtgsen.r

echo "\n-- exA1_z.r:"
Rscript exA1_z.r

echo "\n-- exA2_d.r:"
Rscript exA2_d.r

echo "\n-- exAB1_z.r:"
Rscript exAB1_z.r

echo "\n-- exAB2_d.r:"
Rscript exAB2_d.r
